import { Page } from "@/pages/base";
import { Container, Link, Typography } from "@material-ui/core";
import { Link as RouterLink } from "react-router-dom";
import { route } from "@/routing";
import { InternshipForm } from "@/forms/internship";
import React from "react";
import { ProposalComment } from "@/pages/steps/proposal";
import { useTranslation } from "react-i18next";
import { ProposalPreview } from "@/components/proposalPreview";
import { useSelector } from "react-redux";
import { Internship } from "@/data";
import { AppState } from "@/state/reducer";
import { internshipSerializationTransformer } from "@/serialization";

export const InternshipProposalFormPage = () => {
    return <Page title="Zgłoszenie praktyki">
        <Page.Header maxWidth="md">
            <Page.Breadcrumbs>
                <Link component={ RouterLink } to={ route("home") }>Moja praktyka</Link>
                <Typography color="textPrimary">Zgłoszenie praktyki</Typography>
            </Page.Breadcrumbs>
            <Page.Title>Zgłoszenie praktyki</Page.Title>
        </Page.Header>
        <Container maxWidth={ "md" }>
            <ProposalComment />
            <InternshipForm/>
        </Container>
    </Page>
}

export const InternshipProposalPreviewPage = () => {
    const { t } = useTranslation();
    const proposal = useSelector<AppState, Internship | null>(state => state.proposal.proposal && internshipSerializationTransformer.reverseTransform(state.proposal.proposal));

    return <Page title={ t("") }>
        <Page.Header maxWidth="md">
            <Page.Breadcrumbs>
                <Link component={ RouterLink } to={ route("home") }>Moja praktyka</Link>
                <Typography color="textPrimary">Podgląd zgłoszenia</Typography>
            </Page.Breadcrumbs>
            <Page.Title>Moje zgłoszenie</Page.Title>
        </Page.Header>
        <Container maxWidth={ "md" }>
            <ProposalComment />
            { proposal && <ProposalPreview proposal={ proposal } /> }
        </Container>
    </Page>
}

export default InternshipProposalFormPage;
