import React, { useMemo } from "react";
import { Page } from "@/pages/base";
import { Button, Container, Stepper, Typography } from "@material-ui/core";
import { Link as RouterLink } from "react-router-dom";
import { route } from "@/routing";
import { useTranslation } from "react-i18next";
import { useSelector } from "react-redux";
import { AppState } from "@/state/reducer";
import { getMissingStudentData, Student } from "@/data";
import { Deadlines, Edition, getEditionDeadlines } from "@/data/edition";
import { Step } from "@/components";
import { ProposalStep } from "@/pages/steps/proposal";
import { PlanStep } from "@/pages/steps/plan";
import { InsuranceStep } from "@/pages/steps/insurance";
import { InsuranceState } from "@/state/reducer/insurance";

export const MainPage = () => {
    const { t } = useTranslation();

    const student = useSelector<AppState, Student | null>(state => state.student);
    const deadlines = useSelector<AppState, Deadlines>(state => getEditionDeadlines(state.edition as Edition)); // edition cannot be null at this point
    const insurance = useSelector<AppState, InsuranceState>(root => root.insurance);

    const missingStudentData = useMemo(() => student ? getMissingStudentData(student) : [], [student]);

    return <Page my={ 6 }>
        <Container>
            <Typography variant="h2">{ t("sections.my-internship.header") }</Typography>
            <Stepper orientation="vertical" nonLinear>
                <Step label={ t('steps.personal-data.header') } completed={ missingStudentData.length === 0 } until={ deadlines.personalData }>
                    { missingStudentData.length > 0 && <>
                        <p>{ t('steps.personal-data.info') }</p>

                        <ul>
                            { missingStudentData.map(field => <li key={ field }>{ t(`student.${ field }`) }</li>) }
                        </ul>

                        <Button to={ route("internship_proposal") } variant="contained" color="primary" component={ RouterLink }>
                            { t('steps.personal-data.form') }
                        </Button>
                    </> }
                </Step>
                <ProposalStep />
                <PlanStep />
                { insurance.required && <InsuranceStep /> }
                <Step label={ t('steps.report.header') } until={ deadlines.report }/>
                <Step label={ t('steps.grade.header') }/>
            </Stepper>
        </Container>
    </Page>
}
